@@ -3,9 +3,9 @@ package com.sun.tools.javap.resources;
 public final class version extends java.util.ListResourceBundle {
     protected final Object[][] getContents() {
         return new Object[][] {
-            { "full", "11.0.28-internal+0-adhoc.pkgsrc.jdk11u-jdk-11.0.28-6-1" },
-            { "jdk", "11.0.28" },
-            { "release", "11.0.28-internal" },
+            { "full", "21.0.8-internal-adhoc.pkgsrc.jdk21u-jdk-21.0.8-9-1" },
+            { "jdk", "21.0.8" },
+            { "release", "21.0.8-internal" },
         };
     }
 }
