@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1999, 2024, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 1999, 2022, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -38,7 +38,7 @@ class VersionProps {
 
     // This field is read by HotSpot
     private static final String java_version =
-        "17.0.16-internal";
+        "21.0.8-internal";
 
     private static final String java_version_date =
         "2025-07-15";
@@ -49,34 +49,34 @@ class VersionProps {
 
     // This field is read by HotSpot
     private static final String java_runtime_version =
-        "17.0.16-internal+0-adhoc.pkgsrc.jdk17u-jdk-17.0.16-8-1";
+        "21.0.8-internal-adhoc.pkgsrc.jdk21u-jdk-21.0.8-9-1";
 
     private static final String VERSION_NUMBER =
-        "17.0.16";
+        "21.0.8";
 
     private static final String VERSION_SPECIFICATION =
-        "17";
+        "21";
 
     private static final String VERSION_BUILD =
-        "0";
+        "";
 
     private static final String VERSION_PRE =
         "internal";
 
     private static final String VERSION_OPT =
-        "adhoc.pkgsrc.jdk17u-jdk-17.0.16-8-1";
+        "adhoc.pkgsrc.jdk21u-jdk-21.0.8-9-1";
 
     private static final boolean isLTS =
-        "adhoc.pkgsrc.jdk17u-jdk-17.0.16-8-1".startsWith("LTS");
+        "adhoc.pkgsrc.jdk21u-jdk-21.0.8-9-1".startsWith("LTS");
 
     private static final String CLASSFILE_MAJOR_MINOR =
-        "61.0";
+        "65.0";
 
     private static final String VENDOR =
         "N/A";
 
     private static final String VENDOR_URL =
-        "https://openjdk.java.net/";
+        "https://openjdk.org/";
 
     // The remaining VENDOR_* fields must not be final,
     // so that they can be redefined by jlink plugins
@@ -109,7 +109,10 @@ class VersionProps {
         props.put("java.class.version", CLASSFILE_MAJOR_MINOR);
 
         props.put("java.specification.version", VERSION_SPECIFICATION);
-        props.put("java.specification.maintenance.version", "1");
+
+        // Uncomment next props.put call after the first maintenance release for a
+        // platform specification is done and set the MR number, starting at "1".
+        // props.put("java.specification.maintenance.version", "1");
         props.put("java.specification.name", "Java Platform API Specification");
         props.put("java.specification.vendor", "Oracle Corporation");
 
@@ -183,25 +186,13 @@ class VersionProps {
         }
     }
 
-    /**
-     * In case you were wondering this method is called by java -version.
-     */
-    public static void print(boolean err) {
-        print(err, false);
-    }
 
-    /**
-     * This is the same as print except that it adds an extra line-feed
-     * at the end, typically used by the -showversion in the launcher
-     */
-    public static void println(boolean err) {
-        print(err, true);
-    }
 
     /**
      * Print version info.
+     * In case you were wondering this method is called by java -version.
      */
-    private static void print(boolean err, boolean newln) {
+    private static void print(boolean err) {
         PrintStream ps = err ? System.err : System.out;
 
         /* First line: platform version. */
